# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SyncPolicyEnum(str, Enum):
    """
    * `additive` - additive * `mirror_complete` - mirror_complete * `mirror_content_only` - mirror_content_only
    """

    """
    allowed enum values
    """
    ADDITIVE = 'additive'
    MIRROR_COMPLETE = 'mirror_complete'
    MIRROR_CONTENT_ONLY = 'mirror_content_only'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SyncPolicyEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from pulpcore.client.pulp_rpm.models.policy_enum import PolicyEnum
from typing import Optional, Set
from typing_extensions import Self

class PatchedrpmRpmRemote(BaseModel):
    """
    A Serializer for RpmRemote.
    """ # noqa: E501
    name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A unique name for this remote.")
    url: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The URL of an external content source.")
    ca_cert: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A PEM encoded CA certificate used to validate the server certificate presented by the remote server.")
    client_cert: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A PEM encoded client certificate used for authentication.")
    client_key: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A PEM encoded private key used for authentication.")
    tls_validation: Optional[StrictBool] = Field(default=None, description="If True, TLS peer validation must be performed.")
    proxy_url: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The proxy URL. Format: scheme://host:port")
    proxy_username: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The username to authenticte to the proxy.")
    proxy_password: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The password to authenticate to the proxy. Extra leading and trailing whitespace characters are not trimmed.")
    username: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The username to be used for authentication when syncing.")
    password: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The password to be used for authentication when syncing. Extra leading and trailing whitespace characters are not trimmed.")
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = None
    download_concurrency: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Total number of simultaneous connections. If not set then the default value will be used.")
    max_retries: Optional[StrictInt] = Field(default=None, description="Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.")
    policy: Optional[PolicyEnum] = Field(default=None, description="The policy to use when downloading content. The possible values include: 'immediate', 'on_demand', and 'streamed'. 'immediate' is the default.  * `immediate` - When syncing, download all metadata and content now. * `on_demand` - When syncing, download metadata, but do not download content now. Instead, download content as clients request it, and save it in Pulp to be served for future client requests. * `streamed` - When syncing, download metadata, but do not download content now. Instead,download content as clients request it, but never save it in Pulp. This causes future requests for that same content to have to be downloaded again.")
    total_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    connect_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    sock_connect_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    sock_read_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    headers: Optional[List[Dict[str, Any]]] = Field(default=None, description="Headers for aiohttp.Clientsession")
    rate_limit: Optional[StrictInt] = Field(default=None, description="Limits requests per second for each concurrent downloader")
    sles_auth_token: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Authentication token for SLES repositories.")
    __properties: ClassVar[List[str]] = ["name", "url", "ca_cert", "client_cert", "client_key", "tls_validation", "proxy_url", "proxy_username", "proxy_password", "username", "password", "pulp_labels", "download_concurrency", "max_retries", "policy", "total_timeout", "connect_timeout", "sock_connect_timeout", "sock_read_timeout", "headers", "rate_limit", "sles_auth_token"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PatchedrpmRpmRemote from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if ca_cert (nullable) is None
        # and model_fields_set contains the field
        if self.ca_cert is None and "ca_cert" in self.model_fields_set:
            _dict['ca_cert'] = None

        # set to None if client_cert (nullable) is None
        # and model_fields_set contains the field
        if self.client_cert is None and "client_cert" in self.model_fields_set:
            _dict['client_cert'] = None

        # set to None if client_key (nullable) is None
        # and model_fields_set contains the field
        if self.client_key is None and "client_key" in self.model_fields_set:
            _dict['client_key'] = None

        # set to None if proxy_url (nullable) is None
        # and model_fields_set contains the field
        if self.proxy_url is None and "proxy_url" in self.model_fields_set:
            _dict['proxy_url'] = None

        # set to None if proxy_username (nullable) is None
        # and model_fields_set contains the field
        if self.proxy_username is None and "proxy_username" in self.model_fields_set:
            _dict['proxy_username'] = None

        # set to None if proxy_password (nullable) is None
        # and model_fields_set contains the field
        if self.proxy_password is None and "proxy_password" in self.model_fields_set:
            _dict['proxy_password'] = None

        # set to None if username (nullable) is None
        # and model_fields_set contains the field
        if self.username is None and "username" in self.model_fields_set:
            _dict['username'] = None

        # set to None if password (nullable) is None
        # and model_fields_set contains the field
        if self.password is None and "password" in self.model_fields_set:
            _dict['password'] = None

        # set to None if download_concurrency (nullable) is None
        # and model_fields_set contains the field
        if self.download_concurrency is None and "download_concurrency" in self.model_fields_set:
            _dict['download_concurrency'] = None

        # set to None if max_retries (nullable) is None
        # and model_fields_set contains the field
        if self.max_retries is None and "max_retries" in self.model_fields_set:
            _dict['max_retries'] = None

        # set to None if total_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.total_timeout is None and "total_timeout" in self.model_fields_set:
            _dict['total_timeout'] = None

        # set to None if connect_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.connect_timeout is None and "connect_timeout" in self.model_fields_set:
            _dict['connect_timeout'] = None

        # set to None if sock_connect_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.sock_connect_timeout is None and "sock_connect_timeout" in self.model_fields_set:
            _dict['sock_connect_timeout'] = None

        # set to None if sock_read_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.sock_read_timeout is None and "sock_read_timeout" in self.model_fields_set:
            _dict['sock_read_timeout'] = None

        # set to None if rate_limit (nullable) is None
        # and model_fields_set contains the field
        if self.rate_limit is None and "rate_limit" in self.model_fields_set:
            _dict['rate_limit'] = None

        # set to None if sles_auth_token (nullable) is None
        # and model_fields_set contains the field
        if self.sles_auth_token is None and "sles_auth_token" in self.model_fields_set:
            _dict['sles_auth_token'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PatchedrpmRpmRemote from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_rpm.api.content_modulemd_defaults_api import ContentModulemdDefaultsApi


class TestContentModulemdDefaultsApi(unittest.TestCase):
    """ContentModulemdDefaultsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ContentModulemdDefaultsApi()

    def tearDown(self) -> None:
        pass

    def test_create(self) -> None:
        """Test case for create

        Create a modulemd defaults
        """
        pass

    def test_list(self) -> None:
        """Test case for list

        List modulemd defaultss
        """
        pass

    def test_read(self) -> None:
        """Test case for read

        Inspect a modulemd defaults
        """
        pass

    def test_set_label(self) -> None:
        """Test case for set_label

        Set a label
        """
        pass

    def test_unset_label(self) -> None:
        """Test case for unset_label

        Unset a label
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class RpmModulemdResponse(BaseModel):
    """
    Modulemd serializer.
    """ # noqa: E501
    pulp_href: Optional[StrictStr] = None
    prn: Optional[StrictStr] = Field(default=None, description="The Pulp Resource Name (PRN).")
    pulp_created: Optional[datetime] = Field(default=None, description="Timestamp of creation.")
    pulp_last_updated: Optional[datetime] = Field(default=None, description="Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.")
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = Field(default=None, description="A dictionary of arbitrary key/value pairs used to describe a specific Content instance.")
    vuln_report: Optional[StrictStr] = None
    name: StrictStr = Field(description="Modulemd name.")
    stream: StrictStr = Field(description="Stream name.")
    version: StrictStr = Field(description="Modulemd version.")
    static_context: Optional[StrictBool] = Field(default=None, description="Modulemd static-context flag.")
    context: StrictStr = Field(description="Modulemd context.")
    arch: StrictStr = Field(description="Modulemd architecture.")
    artifacts: Optional[Any] = Field(description="Modulemd artifacts.")
    dependencies: Optional[Any] = Field(description="Modulemd dependencies.")
    packages: Optional[List[Optional[StrictStr]]] = Field(default=None, description="Modulemd artifacts' packages.")
    profiles: Optional[Any] = Field(description="Modulemd profiles.")
    description: StrictStr = Field(description="Description of module.")
    __properties: ClassVar[List[str]] = ["pulp_href", "prn", "pulp_created", "pulp_last_updated", "pulp_labels", "vuln_report", "name", "stream", "version", "static_context", "context", "arch", "artifacts", "dependencies", "packages", "profiles", "description"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RpmModulemdResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pulp_href",
            "prn",
            "pulp_created",
            "pulp_last_updated",
            "vuln_report",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if artifacts (nullable) is None
        # and model_fields_set contains the field
        if self.artifacts is None and "artifacts" in self.model_fields_set:
            _dict['artifacts'] = None

        # set to None if dependencies (nullable) is None
        # and model_fields_set contains the field
        if self.dependencies is None and "dependencies" in self.model_fields_set:
            _dict['dependencies'] = None

        # set to None if profiles (nullable) is None
        # and model_fields_set contains the field
        if self.profiles is None and "profiles" in self.model_fields_set:
            _dict['profiles'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RpmModulemdResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "3.32.4"

# Define package exports
__all__ = [
    "AcsRpmApi",
    "ContentAdvisoriesApi",
    "ContentDistributionTreesApi",
    "ContentModulemdDefaultsApi",
    "ContentModulemdObsoletesApi",
    "ContentModulemdsApi",
    "ContentPackagecategoriesApi",
    "ContentPackageenvironmentsApi",
    "ContentPackagegroupsApi",
    "ContentPackagelangpacksApi",
    "ContentPackagesApi",
    "ContentRepoMetadataFilesApi",
    "DistributionsRpmApi",
    "PublicationsRpmApi",
    "RemotesRpmApi",
    "RemotesUlnApi",
    "RepositoriesRpmApi",
    "RepositoriesRpmVersionsApi",
    "RpmCompsApi",
    "RpmCopyApi",
    "RpmPruneApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AddonResponse",
    "ArtifactResponse",
    "AsyncOperationResponse",
    "ChecksumResponse",
    "CompressionTypeEnum",
    "ContentSummaryResponse",
    "Copy",
    "ImageResponse",
    "LayoutEnum",
    "MyPermissionsResponse",
    "NestedRole",
    "NestedRoleResponse",
    "ObjectRolesResponse",
    "PackageChecksumTypeEnum",
    "PaginatedRepositoryVersionResponseList",
    "PaginatedrpmDistributionTreeResponseList",
    "PaginatedrpmModulemdDefaultsResponseList",
    "PaginatedrpmModulemdObsoleteResponseList",
    "PaginatedrpmModulemdResponseList",
    "PaginatedrpmPackageCategoryResponseList",
    "PaginatedrpmPackageEnvironmentResponseList",
    "PaginatedrpmPackageGroupResponseList",
    "PaginatedrpmPackageLangpacksResponseList",
    "PaginatedrpmPackageResponseList",
    "PaginatedrpmRepoMetadataFileResponseList",
    "PaginatedrpmRpmAlternateContentSourceResponseList",
    "PaginatedrpmRpmDistributionResponseList",
    "PaginatedrpmRpmPublicationResponseList",
    "PaginatedrpmRpmRemoteResponseList",
    "PaginatedrpmRpmRepositoryResponseList",
    "PaginatedrpmUlnRemoteResponseList",
    "PaginatedrpmUpdateRecordResponseList",
    "PatchedrpmRpmAlternateContentSource",
    "PatchedrpmRpmDistribution",
    "PatchedrpmRpmRemote",
    "PatchedrpmRpmRepository",
    "PatchedrpmUlnRemote",
    "PolicyEnum",
    "PrunePackages",
    "Repair",
    "RepositoryAddRemoveContent",
    "RepositoryVersionResponse",
    "RpmDistributionTreeResponse",
    "RpmModulemd",
    "RpmModulemdDefaults",
    "RpmModulemdDefaultsResponse",
    "RpmModulemdObsolete",
    "RpmModulemdObsoleteResponse",
    "RpmModulemdResponse",
    "RpmPackageCategoryResponse",
    "RpmPackageEnvironmentResponse",
    "RpmPackageGroupResponse",
    "RpmPackageLangpacksResponse",
    "RpmPackageResponse",
    "RpmRepoMetadataFileResponse",
    "RpmRepositorySyncURL",
    "RpmRpmAlternateContentSource",
    "RpmRpmAlternateContentSourceResponse",
    "RpmRpmDistribution",
    "RpmRpmDistributionResponse",
    "RpmRpmPublication",
    "RpmRpmPublicationResponse",
    "RpmRpmRemote",
    "RpmRpmRemoteResponse",
    "RpmRpmRemoteResponseHiddenFieldsInner",
    "RpmRpmRepository",
    "RpmRpmRepositoryResponse",
    "RpmUlnRemote",
    "RpmUlnRemoteResponse",
    "RpmUpdateCollection",
    "RpmUpdateCollectionResponse",
    "RpmUpdateRecordResponse",
    "SetLabel",
    "SetLabelResponse",
    "SkipTypesEnum",
    "SyncPolicyEnum",
    "TaskGroupOperationResponse",
    "UnsetLabel",
    "UnsetLabelResponse",
    "VariantResponse",
]

# import apis into sdk package
from pulpcore.client.pulp_rpm.api.acs_rpm_api import AcsRpmApi as AcsRpmApi
from pulpcore.client.pulp_rpm.api.content_advisories_api import ContentAdvisoriesApi as ContentAdvisoriesApi
from pulpcore.client.pulp_rpm.api.content_distribution_trees_api import ContentDistributionTreesApi as ContentDistributionTreesApi
from pulpcore.client.pulp_rpm.api.content_modulemd_defaults_api import ContentModulemdDefaultsApi as ContentModulemdDefaultsApi
from pulpcore.client.pulp_rpm.api.content_modulemd_obsoletes_api import ContentModulemdObsoletesApi as ContentModulemdObsoletesApi
from pulpcore.client.pulp_rpm.api.content_modulemds_api import ContentModulemdsApi as ContentModulemdsApi
from pulpcore.client.pulp_rpm.api.content_packagecategories_api import ContentPackagecategoriesApi as ContentPackagecategoriesApi
from pulpcore.client.pulp_rpm.api.content_packageenvironments_api import ContentPackageenvironmentsApi as ContentPackageenvironmentsApi
from pulpcore.client.pulp_rpm.api.content_packagegroups_api import ContentPackagegroupsApi as ContentPackagegroupsApi
from pulpcore.client.pulp_rpm.api.content_packagelangpacks_api import ContentPackagelangpacksApi as ContentPackagelangpacksApi
from pulpcore.client.pulp_rpm.api.content_packages_api import ContentPackagesApi as ContentPackagesApi
from pulpcore.client.pulp_rpm.api.content_repo_metadata_files_api import ContentRepoMetadataFilesApi as ContentRepoMetadataFilesApi
from pulpcore.client.pulp_rpm.api.distributions_rpm_api import DistributionsRpmApi as DistributionsRpmApi
from pulpcore.client.pulp_rpm.api.publications_rpm_api import PublicationsRpmApi as PublicationsRpmApi
from pulpcore.client.pulp_rpm.api.remotes_rpm_api import RemotesRpmApi as RemotesRpmApi
from pulpcore.client.pulp_rpm.api.remotes_uln_api import RemotesUlnApi as RemotesUlnApi
from pulpcore.client.pulp_rpm.api.repositories_rpm_api import RepositoriesRpmApi as RepositoriesRpmApi
from pulpcore.client.pulp_rpm.api.repositories_rpm_versions_api import RepositoriesRpmVersionsApi as RepositoriesRpmVersionsApi
from pulpcore.client.pulp_rpm.api.rpm_comps_api import RpmCompsApi as RpmCompsApi
from pulpcore.client.pulp_rpm.api.rpm_copy_api import RpmCopyApi as RpmCopyApi
from pulpcore.client.pulp_rpm.api.rpm_prune_api import RpmPruneApi as RpmPruneApi

# import ApiClient
from pulpcore.client.pulp_rpm.api_response import ApiResponse as ApiResponse
from pulpcore.client.pulp_rpm.api_client import ApiClient as ApiClient
from pulpcore.client.pulp_rpm.configuration import Configuration as Configuration
from pulpcore.client.pulp_rpm.exceptions import OpenApiException as OpenApiException
from pulpcore.client.pulp_rpm.exceptions import ApiTypeError as ApiTypeError
from pulpcore.client.pulp_rpm.exceptions import ApiValueError as ApiValueError
from pulpcore.client.pulp_rpm.exceptions import ApiKeyError as ApiKeyError
from pulpcore.client.pulp_rpm.exceptions import ApiAttributeError as ApiAttributeError
from pulpcore.client.pulp_rpm.exceptions import ApiException as ApiException

# import models into sdk package
from pulpcore.client.pulp_rpm.models.addon_response import AddonResponse as AddonResponse
from pulpcore.client.pulp_rpm.models.artifact_response import ArtifactResponse as ArtifactResponse
from pulpcore.client.pulp_rpm.models.async_operation_response import AsyncOperationResponse as AsyncOperationResponse
from pulpcore.client.pulp_rpm.models.checksum_response import ChecksumResponse as ChecksumResponse
from pulpcore.client.pulp_rpm.models.compression_type_enum import CompressionTypeEnum as CompressionTypeEnum
from pulpcore.client.pulp_rpm.models.content_summary_response import ContentSummaryResponse as ContentSummaryResponse
from pulpcore.client.pulp_rpm.models.copy import Copy as Copy
from pulpcore.client.pulp_rpm.models.image_response import ImageResponse as ImageResponse
from pulpcore.client.pulp_rpm.models.layout_enum import LayoutEnum as LayoutEnum
from pulpcore.client.pulp_rpm.models.my_permissions_response import MyPermissionsResponse as MyPermissionsResponse
from pulpcore.client.pulp_rpm.models.nested_role import NestedRole as NestedRole
from pulpcore.client.pulp_rpm.models.nested_role_response import NestedRoleResponse as NestedRoleResponse
from pulpcore.client.pulp_rpm.models.object_roles_response import ObjectRolesResponse as ObjectRolesResponse
from pulpcore.client.pulp_rpm.models.package_checksum_type_enum import PackageChecksumTypeEnum as PackageChecksumTypeEnum
from pulpcore.client.pulp_rpm.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList as PaginatedRepositoryVersionResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_distribution_tree_response_list import PaginatedrpmDistributionTreeResponseList as PaginatedrpmDistributionTreeResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_modulemd_defaults_response_list import PaginatedrpmModulemdDefaultsResponseList as PaginatedrpmModulemdDefaultsResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_modulemd_obsolete_response_list import PaginatedrpmModulemdObsoleteResponseList as PaginatedrpmModulemdObsoleteResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_modulemd_response_list import PaginatedrpmModulemdResponseList as PaginatedrpmModulemdResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_package_category_response_list import PaginatedrpmPackageCategoryResponseList as PaginatedrpmPackageCategoryResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_package_environment_response_list import PaginatedrpmPackageEnvironmentResponseList as PaginatedrpmPackageEnvironmentResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_package_group_response_list import PaginatedrpmPackageGroupResponseList as PaginatedrpmPackageGroupResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_package_langpacks_response_list import PaginatedrpmPackageLangpacksResponseList as PaginatedrpmPackageLangpacksResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_package_response_list import PaginatedrpmPackageResponseList as PaginatedrpmPackageResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_repo_metadata_file_response_list import PaginatedrpmRepoMetadataFileResponseList as PaginatedrpmRepoMetadataFileResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_rpm_alternate_content_source_response_list import PaginatedrpmRpmAlternateContentSourceResponseList as PaginatedrpmRpmAlternateContentSourceResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_rpm_distribution_response_list import PaginatedrpmRpmDistributionResponseList as PaginatedrpmRpmDistributionResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_rpm_publication_response_list import PaginatedrpmRpmPublicationResponseList as PaginatedrpmRpmPublicationResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_rpm_remote_response_list import PaginatedrpmRpmRemoteResponseList as PaginatedrpmRpmRemoteResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_rpm_repository_response_list import PaginatedrpmRpmRepositoryResponseList as PaginatedrpmRpmRepositoryResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_uln_remote_response_list import PaginatedrpmUlnRemoteResponseList as PaginatedrpmUlnRemoteResponseList
from pulpcore.client.pulp_rpm.models.paginatedrpm_update_record_response_list import PaginatedrpmUpdateRecordResponseList as PaginatedrpmUpdateRecordResponseList
from pulpcore.client.pulp_rpm.models.patchedrpm_rpm_alternate_content_source import PatchedrpmRpmAlternateContentSource as PatchedrpmRpmAlternateContentSource
from pulpcore.client.pulp_rpm.models.patchedrpm_rpm_distribution import PatchedrpmRpmDistribution as PatchedrpmRpmDistribution
from pulpcore.client.pulp_rpm.models.patchedrpm_rpm_remote import PatchedrpmRpmRemote as PatchedrpmRpmRemote
from pulpcore.client.pulp_rpm.models.patchedrpm_rpm_repository import PatchedrpmRpmRepository as PatchedrpmRpmRepository
from pulpcore.client.pulp_rpm.models.patchedrpm_uln_remote import PatchedrpmUlnRemote as PatchedrpmUlnRemote
from pulpcore.client.pulp_rpm.models.policy_enum import PolicyEnum as PolicyEnum
from pulpcore.client.pulp_rpm.models.prune_packages import PrunePackages as PrunePackages
from pulpcore.client.pulp_rpm.models.repair import Repair as Repair
from pulpcore.client.pulp_rpm.models.repository_add_remove_content import RepositoryAddRemoveContent as RepositoryAddRemoveContent
from pulpcore.client.pulp_rpm.models.repository_version_response import RepositoryVersionResponse as RepositoryVersionResponse
from pulpcore.client.pulp_rpm.models.rpm_distribution_tree_response import RpmDistributionTreeResponse as RpmDistributionTreeResponse
from pulpcore.client.pulp_rpm.models.rpm_modulemd import RpmModulemd as RpmModulemd
from pulpcore.client.pulp_rpm.models.rpm_modulemd_defaults import RpmModulemdDefaults as RpmModulemdDefaults
from pulpcore.client.pulp_rpm.models.rpm_modulemd_defaults_response import RpmModulemdDefaultsResponse as RpmModulemdDefaultsResponse
from pulpcore.client.pulp_rpm.models.rpm_modulemd_obsolete import RpmModulemdObsolete as RpmModulemdObsolete
from pulpcore.client.pulp_rpm.models.rpm_modulemd_obsolete_response import RpmModulemdObsoleteResponse as RpmModulemdObsoleteResponse
from pulpcore.client.pulp_rpm.models.rpm_modulemd_response import RpmModulemdResponse as RpmModulemdResponse
from pulpcore.client.pulp_rpm.models.rpm_package_category_response import RpmPackageCategoryResponse as RpmPackageCategoryResponse
from pulpcore.client.pulp_rpm.models.rpm_package_environment_response import RpmPackageEnvironmentResponse as RpmPackageEnvironmentResponse
from pulpcore.client.pulp_rpm.models.rpm_package_group_response import RpmPackageGroupResponse as RpmPackageGroupResponse
from pulpcore.client.pulp_rpm.models.rpm_package_langpacks_response import RpmPackageLangpacksResponse as RpmPackageLangpacksResponse
from pulpcore.client.pulp_rpm.models.rpm_package_response import RpmPackageResponse as RpmPackageResponse
from pulpcore.client.pulp_rpm.models.rpm_repo_metadata_file_response import RpmRepoMetadataFileResponse as RpmRepoMetadataFileResponse
from pulpcore.client.pulp_rpm.models.rpm_repository_sync_url import RpmRepositorySyncURL as RpmRepositorySyncURL
from pulpcore.client.pulp_rpm.models.rpm_rpm_alternate_content_source import RpmRpmAlternateContentSource as RpmRpmAlternateContentSource
from pulpcore.client.pulp_rpm.models.rpm_rpm_alternate_content_source_response import RpmRpmAlternateContentSourceResponse as RpmRpmAlternateContentSourceResponse
from pulpcore.client.pulp_rpm.models.rpm_rpm_distribution import RpmRpmDistribution as RpmRpmDistribution
from pulpcore.client.pulp_rpm.models.rpm_rpm_distribution_response import RpmRpmDistributionResponse as RpmRpmDistributionResponse
from pulpcore.client.pulp_rpm.models.rpm_rpm_publication import RpmRpmPublication as RpmRpmPublication
from pulpcore.client.pulp_rpm.models.rpm_rpm_publication_response import RpmRpmPublicationResponse as RpmRpmPublicationResponse
from pulpcore.client.pulp_rpm.models.rpm_rpm_remote import RpmRpmRemote as RpmRpmRemote
from pulpcore.client.pulp_rpm.models.rpm_rpm_remote_response import RpmRpmRemoteResponse as RpmRpmRemoteResponse
from pulpcore.client.pulp_rpm.models.rpm_rpm_remote_response_hidden_fields_inner import RpmRpmRemoteResponseHiddenFieldsInner as RpmRpmRemoteResponseHiddenFieldsInner
from pulpcore.client.pulp_rpm.models.rpm_rpm_repository import RpmRpmRepository as RpmRpmRepository
from pulpcore.client.pulp_rpm.models.rpm_rpm_repository_response import RpmRpmRepositoryResponse as RpmRpmRepositoryResponse
from pulpcore.client.pulp_rpm.models.rpm_uln_remote import RpmUlnRemote as RpmUlnRemote
from pulpcore.client.pulp_rpm.models.rpm_uln_remote_response import RpmUlnRemoteResponse as RpmUlnRemoteResponse
from pulpcore.client.pulp_rpm.models.rpm_update_collection import RpmUpdateCollection as RpmUpdateCollection
from pulpcore.client.pulp_rpm.models.rpm_update_collection_response import RpmUpdateCollectionResponse as RpmUpdateCollectionResponse
from pulpcore.client.pulp_rpm.models.rpm_update_record_response import RpmUpdateRecordResponse as RpmUpdateRecordResponse
from pulpcore.client.pulp_rpm.models.set_label import SetLabel as SetLabel
from pulpcore.client.pulp_rpm.models.set_label_response import SetLabelResponse as SetLabelResponse
from pulpcore.client.pulp_rpm.models.skip_types_enum import SkipTypesEnum as SkipTypesEnum
from pulpcore.client.pulp_rpm.models.sync_policy_enum import SyncPolicyEnum as SyncPolicyEnum
from pulpcore.client.pulp_rpm.models.task_group_operation_response import TaskGroupOperationResponse as TaskGroupOperationResponse
from pulpcore.client.pulp_rpm.models.unset_label import UnsetLabel as UnsetLabel
from pulpcore.client.pulp_rpm.models.unset_label_response import UnsetLabelResponse as UnsetLabelResponse
from pulpcore.client.pulp_rpm.models.variant_response import VariantResponse as VariantResponse



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_rpm.models.paginatedrpm_distribution_tree_response_list import PaginatedrpmDistributionTreeResponseList

class TestPaginatedrpmDistributionTreeResponseList(unittest.TestCase):
    """PaginatedrpmDistributionTreeResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedrpmDistributionTreeResponseList:
        """Test PaginatedrpmDistributionTreeResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedrpmDistributionTreeResponseList`
        """
        model = PaginatedrpmDistributionTreeResponseList()
        if include_optional:
            return PaginatedrpmDistributionTreeResponseList(
                count = 123,
                next = 'http://api.example.org/accounts/?offset=400&limit=100',
                previous = 'http://api.example.org/accounts/?offset=200&limit=100',
                results = [
                    pulpcore.client.pulp_rpm.models.rpm/distribution_tree_response.rpm.DistributionTreeResponse(
                        pulp_href = '', 
                        prn = '', 
                        header_version = '', 
                        release_name = '', 
                        release_short = '', 
                        release_version = '', 
                        release_is_layered = True, 
                        base_product_name = '', 
                        base_product_short = '', 
                        base_product_version = '', 
                        arch = '', 
                        build_timestamp = 1.337, 
                        instimage = '', 
                        mainimage = '', 
                        discnum = 56, 
                        totaldiscs = 56, 
                        addons = [
                            pulpcore.client.pulp_rpm.models.addon_response.AddonResponse(
                                addon_id = '', 
                                uid = '', 
                                name = '', 
                                type = '', 
                                packages = '', )
                            ], 
                        checksums = [
                            pulpcore.client.pulp_rpm.models.checksum_response.ChecksumResponse(
                                path = '', 
                                checksum = '', )
                            ], 
                        images = [
                            pulpcore.client.pulp_rpm.models.image_response.ImageResponse(
                                name = '', 
                                path = '', 
                                platforms = '', 
                                artifact = null, )
                            ], 
                        variants = [
                            pulpcore.client.pulp_rpm.models.variant_response.VariantResponse(
                                variant_id = '', 
                                uid = '', 
                                name = '', 
                                type = '', 
                                packages = '', 
                                source_packages = '', 
                                source_repository = '', 
                                debug_packages = '', 
                                debug_repository = '', 
                                identity = '', )
                            ], )
                    ]
            )
        else:
            return PaginatedrpmDistributionTreeResponseList(
                count = 123,
                results = [
                    pulpcore.client.pulp_rpm.models.rpm/distribution_tree_response.rpm.DistributionTreeResponse(
                        pulp_href = '', 
                        prn = '', 
                        header_version = '', 
                        release_name = '', 
                        release_short = '', 
                        release_version = '', 
                        release_is_layered = True, 
                        base_product_name = '', 
                        base_product_short = '', 
                        base_product_version = '', 
                        arch = '', 
                        build_timestamp = 1.337, 
                        instimage = '', 
                        mainimage = '', 
                        discnum = 56, 
                        totaldiscs = 56, 
                        addons = [
                            pulpcore.client.pulp_rpm.models.addon_response.AddonResponse(
                                addon_id = '', 
                                uid = '', 
                                name = '', 
                                type = '', 
                                packages = '', )
                            ], 
                        checksums = [
                            pulpcore.client.pulp_rpm.models.checksum_response.ChecksumResponse(
                                path = '', 
                                checksum = '', )
                            ], 
                        images = [
                            pulpcore.client.pulp_rpm.models.image_response.ImageResponse(
                                name = '', 
                                path = '', 
                                platforms = '', 
                                artifact = null, )
                            ], 
                        variants = [
                            pulpcore.client.pulp_rpm.models.variant_response.VariantResponse(
                                variant_id = '', 
                                uid = '', 
                                name = '', 
                                type = '', 
                                packages = '', 
                                source_packages = '', 
                                source_repository = '', 
                                debug_packages = '', 
                                debug_repository = '', 
                                identity = '', )
                            ], )
                    ],
        )
        """

    def testPaginatedrpmDistributionTreeResponseList(self):
        """Test PaginatedrpmDistributionTreeResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
